/****************************************************************************
 * Functions to load fonts.
 * Copyright (C) 2004 Joe Wingbermuehle
 ****************************************************************************/

#include "jwm.h"

static const char *DEFAULT_BORDER_FONT = "-*-times-*-r-*-*-*-*-*-*-*-*-*-*";
static const char *DEFAULT_TRAY_FONT = "-*-times-*-r-*-*-*-*-*-*-*-*-*-*";
static const char *DEFAULT_MENU_FONT = "-*-times-*-r-*-*-*-*-*-*-*-*-*-*";

static char *borderFontName = NULL;
static char *trayFontName = NULL;
static char *menuFontName = NULL;

XFontStruct *borderFont = NULL;
XFontStruct *trayFont = NULL;
XFontStruct *menuFont = NULL;

/****************************************************************************
 ****************************************************************************/
void InitializeFonts() {

	borderFont = XLoadQueryFont(display, borderFontName);
	if(!borderFont) {
		borderFont = XLoadQueryFont(display, DEFAULT_BORDER_FONT);
		if(!borderFont) {
			FatalError("Could not load the default border font");
		}
	}

	trayFont = XLoadQueryFont(display, trayFontName);
	if(!trayFont) {
		trayFont = XLoadQueryFont(display, DEFAULT_TRAY_FONT);
		if(!trayFont) {
			FatalError("Could not load the default tray font");
		}
	}

	menuFont = XLoadQueryFont(display, menuFontName);
	if(!menuFont) {
		menuFont = XLoadQueryFont(display, DEFAULT_MENU_FONT);
		if(!menuFont) {
			FatalError("Could not load the default menu font");
		}
	}

}

/****************************************************************************
 ****************************************************************************/
void SetBorderFont(const char *fontName) {
	if(borderFontName) {
		Release(borderFontName);
		borderFontName = NULL;
	}
	if(fontName) {
		borderFontName = Allocate(strlen(fontName) + 1);
		strcpy(borderFontName, fontName);
	}
}

/****************************************************************************
 ****************************************************************************/
void SetTrayFont(const char *fontName) {
	if(trayFontName) {
		Release(trayFontName);
		trayFontName = NULL;
	}
	if(fontName) {
		trayFontName = Allocate(strlen(fontName) + 1);
		strcpy(trayFontName, fontName);
	}
}

/****************************************************************************
 ****************************************************************************/
void SetMenuFont(const char *fontName) {
	if(menuFontName) {
		Release(menuFontName);
		menuFontName = NULL;
	}
	if(fontName) {
		menuFontName = Allocate(strlen(fontName) + 1);
		strcpy(menuFontName, fontName);
	}
}

/****************************************************************************
 ****************************************************************************/
void ReleaseFonts() {
	if(borderFont) {
		XFreeFont(display, borderFont);
		borderFont = NULL;
	}
	if(trayFont) {
		XFreeFont(display, trayFont);
		trayFont = NULL;
	}
	if(menuFont) {
		XFreeFont(display, menuFont);
		menuFont = NULL;
	}

	if(borderFontName) {
		Release(borderFontName);
		borderFontName = NULL;
	}
	if(trayFontName) {
		Release(trayFontName);
		trayFontName = NULL;
	}
	if(menuFontName) {
		Release(menuFontName);
		menuFontName = NULL;
	}

}


