/****************************************************************************
 * Functions for obtaining load information.
 * Copyright (C) 2004 Joe Wingbermuehle
 ****************************************************************************/

#include "jwm.h"

#ifdef SHOW_LOAD

#ifdef sgi
	#include <sys/sysget.h>
#endif /* sgi */
#ifdef linux
	#include <sys/sysinfo.h>
#endif

static const int LOAD_DELTA = 5;

static int loadHeight;
static Pixmap loadDisplay;
static GC loadGC;
static time_t lastTime;
static float loads[LOAD_WIDTH];

static void UpdateLoadDisplay();

#endif /* SHOW_LOAD */

/****************************************************************************
 ****************************************************************************/
void InitializeLoadDisplay() {
#ifdef SHOW_LOAD
	int x;

	loadHeight = TRAY_HEIGHT - 4;

	loadDisplay = XCreatePixmap(display, rootWindow, LOAD_WIDTH,
		loadHeight, DefaultDepth(display, DefaultScreen(display)));
	loadGC = XCreateGC(display, loadDisplay, 0, NULL);

	for(x = 0; x < LOAD_WIDTH; x++) {
		loads[x] = 0.0;
	}

	UpdateLoadDisplay();
#endif
}

/****************************************************************************
 ****************************************************************************/
void DestroyLoadDisplay() {
#ifdef SHOW_LOAD
	XFreeGC(display, loadGC);
	XFreePixmap(display, loadDisplay);
#endif
}

/****************************************************************************
 ****************************************************************************/
void UpdateLoadDisplay() {
#ifdef SHOW_LOAD

#ifdef sgi
	struct sgt_cookie cookie;
	int load[3];
#endif /* sgi */
#ifdef linux
	struct sysinfo info;
#endif
	float currentLoad = 0.0;
	int loadLines;
	float divideSize, y;
	int x;

	lastTime = time(NULL);

	/* Compute the current load. */
#ifdef sgi
	SGT_COOKIE_INIT(&cookie);
	SGT_COOKIE_SET_KSYM(&cookie, KSYM_AVENRUN);
	if(sysget(SGT_KSYM, (char*)load, sizeof(load), SGT_READ, &cookie) == -1) {
		Debug("sysget failed");
		return;
	}
	currentLoad = (float)load[0] / 1024.0;
#endif /* sgi */
#ifdef linux
	if(sysinfo(&info) == -1) {
		Debug("sysinfo failed");
		return;
	}
	currentLoad = (float)info.loads[0] / 65536.0;
#endif

	/* Update the array and determine how many load lines to draw. */
	loadLines = (int)currentLoad;
	for(x = 0; x < LOAD_WIDTH - 1; x++) {
		loads[x] = loads[x + 1];
		if((int)loads[x] > loadLines) {
			loadLines = (int)loads[x];
		}
	}
	loads[LOAD_WIDTH - 1] = currentLoad;

	/* Clear the draw area. */
	XSetForeground(display, loadGC, colors[COLOR_BORDER]);
	XFillRectangle(display, loadDisplay, loadGC, 0, 0,
		LOAD_WIDTH, loadHeight);

	/* Draw the graph. */
	XSetForeground(display, loadGC, colors[COLOR_ACTIVE_BORDER]);
	for(x = 0; x < LOAD_WIDTH; x++) {
		y = (loads[x] * loadHeight) / (loadLines + 1);
		XDrawLine(display, loadDisplay, loadGC, x, loadHeight - (int)y,
			x, loadHeight);
	}

	/* Draw load lines */
	divideSize = (float)(loadHeight) / (float)(loadLines + 1);
	XSetForeground(display, loadGC, colors[COLOR_BORDER_TEXT]);
	y = divideSize;
	for(x = 0; x < loadLines; x++) {
		XDrawLine(display, loadDisplay, loadGC, 0, (int)y,
			LOAD_WIDTH, (int)y);
		y += divideSize;
	}

#endif /* SHOW_LOAD */

}

/****************************************************************************
 ****************************************************************************/
Pixmap GetLoadDisplay() {
#ifdef SHOW_LOAD

	if(time(NULL) - lastTime >= LOAD_DELTA) {
		UpdateLoadDisplay();
	}

	return loadDisplay;
#else
	return 0;
#endif
}

