/***************************************************************************
 * Functions to handle the root menu.
 * Copyright (C) 2004 Joe Wingbermuehle
 ***************************************************************************/

#include "jwm.h"

static void RunCommand(const char *command);

static MenuType *rootMenu = NULL;

/***************************************************************************
 ***************************************************************************/
void SetRootMenu(MenuType *m) {
	if(rootMenu) {
		DestroyRootMenu();
	}
	rootMenu = m;
}

/***************************************************************************
 ***************************************************************************/
void DestroyRootMenu() {
	DestroyMenu(rootMenu);
	rootMenu = NULL;
}

/***************************************************************************
 ***************************************************************************/
void ShowRootMenu(int x, int y) {

	if(!rootMenu) {
		return;
	}

	ShowMenu(rootMenu, RunCommand, x, y);

}

/***************************************************************************
 ***************************************************************************/
void RunCommand(const char *command) {
	char *displayString;
	char *str;

	if(!command) {
		return;
	}

	if(!strcmp(command, "#exit")) {
		shouldExit = 1;
		return;
	} else if(!strcmp(command, "#restart")) {
		shouldRestart = 1;
		shouldExit = 1;
		return;
	}

	displayString = DisplayString(display);

	if(!fork()) {
		if(!fork()) {
			close(ConnectionNumber(display));
			if(displayString && displayString[0]) {
				str = malloc(strlen(displayString) + 9);
				sprintf(str, "DISPLAY=%s", displayString);
				putenv(str);
			}
			execl(SHELL_NAME, SHELL_NAME, "-c", command, NULL);
			fprintf(stderr, "exec failed\n");
			exit(1);
		}
		exit(0);
	}

	wait(NULL);

}

